@@ -1,5 +1,6 @@
 # Copyright 2020 StackHut Limited (trading as Datapane)
 # SPDX-License-Identifier: Apache-2.0
-# flake8: noqa F401
 
 from .utils import DPError
+
+__all__ = ["DPError"]
