@@ -24,7 +24,8 @@ APP_NAME = "datapane"
 APP_DIR = Path(click.get_app_dir(APP_NAME))
 APP_DIR.mkdir(parents=True, exist_ok=True)
 DEFAULT_ENV = "default"
-DEFAULT_SERVER = "https://datapane.com"
+PAST_DEFAULT_SERVER = "https://datapane.com"
+DEFAULT_SERVER = "https://cloud.datapane.com"
 DEFAULT_TOKEN = "TOKEN_HERE"
 LATEST_VERSION = 4
 
@@ -91,10 +92,11 @@ class Config:
         c_yaml["from_file"] = True
 
         # NOTE - type checker doesn't like us setting class variables on instance
-        config = dacite.from_dict(Config, c_yaml)
+        config: Config = dacite.from_dict(Config, c_yaml)
         config._env = env
         config._path = config_f
         log.debug(f"Loaded client environment from {config._path}")
+
         # check if stored file is out of date
         config.upgrade_config_format()
 
@@ -121,8 +123,8 @@ class Config:
 
         with self._path.open("w") as f:
             config_dictionary = dc.asdict(self)
-            config_dictionary["_path"] = None
-            config_dictionary["_env"] = None
+            del config_dictionary["_path"]
+            del config_dictionary["_env"]
             yaml.safe_dump(config_dictionary, f)
 
     def remove(self):
@@ -135,7 +137,11 @@ class Config:
     def upgrade_config_format(self):
         """Handles updating the older config format
         - we default to the oldest version with default values, and upgrade here
+        - TODO - switch this to stdlib configparser
         """
+        # this isn't tied to a particular config version
+        if self.server == PAST_DEFAULT_SERVER:
+            self.server = DEFAULT_SERVER
 
         # migrate older config files
         if self.version in (1, 2, 3):
@@ -154,9 +160,12 @@ class Config:
 
                     capture("CLI Login", config=self, with_token=True)
 
-            self.version = 4
+            self.version = 5
             self.save()
         elif self.version == 4:
+            self.version = 5
+            self.save()  # trigger removal of _env & _pass from file
+        elif self.version == 5:
             pass  # current
 
 
