@@ -1,5 +1,6 @@
 import datetime
 import gzip
+import io
 import locale
 import logging
 import logging.config
@@ -12,15 +13,15 @@ import time
 import typing as t
 from contextlib import contextmanager
 from pathlib import Path
-from tempfile import NamedTemporaryFile, TemporaryDirectory, mkstemp
+from tempfile import NamedTemporaryFile, TemporaryDirectory, _TemporaryFileWrapper, mkstemp
 
 import chardet
 import importlib_resources as ir
 from chardet.universaldetector import UniversalDetector
 
-from .dp_types import MIME, DPError, DPMode, NPath, get_dp_mode
+from .dp_types import MIME, DPMode, NPath, SDict, get_dp_mode
 
-mimetypes.init(files=[ir.files("datapane.resources") / "mime.types"])
+mimetypes.init(files=[str(ir.files("datapane.resources") / "mime.types")])
 
 # TODO - hardcode as temporary fix until mimetypes double extension issue is sorted
 _double_ext_map = {
@@ -31,6 +32,7 @@ _double_ext_map = {
     ".bokeh.json": "application/vnd.bokeh.show+json",
     ".pl.json": "application/vnd.plotly.v1+json",
     ".fl.html": "application/vnd.folium+html",
+    ".plotapi.html": "application/vnd.plotapi+html",
     ".tbl.html": "application/vnd.datapane.table+html",
     ".tar.gz": "application/x-tgz",
 }
@@ -124,7 +126,7 @@ def enable_logging():
 
 
 @contextmanager
-def log_command(command: str) -> t.ContextManager[None]:
+def log_command(command: str) -> t.Generator[None, None, None]:
     """Log an internal process"""
     log.info(f"Starting {command}")
     yield
@@ -134,7 +136,7 @@ def log_command(command: str) -> t.ContextManager[None]:
 @contextmanager
 def create_temp_file(
     suffix: str, prefix: str = "datapane-temp-", mode: str = "w+b"
-) -> t.ContextManager[NamedTemporaryFile]:
+) -> t.Generator[_TemporaryFileWrapper, None, None]:
     """Creates a NamedTemporaryFile that doesn't disappear on .close()"""
     temp_file = NamedTemporaryFile(suffix=suffix, prefix=prefix, mode=mode, delete=False)
     try:
@@ -144,7 +146,7 @@ def create_temp_file(
 
 
 @contextmanager
-def temp_fname(suffix: str, prefix: str = "datapane-temp-", keep: bool = False) -> t.ContextManager[str]:
+def temp_fname(suffix: str, prefix: str = "datapane-temp-", keep: bool = False) -> t.Generator[str, None, None]:
     """Wrapper to generate a temporary filename only that is deleted on leaving context"""
     # TODO - return Path
     (in_f, in_f_name) = mkstemp(suffix=suffix, prefix=prefix)
@@ -157,7 +159,7 @@ def temp_fname(suffix: str, prefix: str = "datapane-temp-", keep: bool = False)
 
 
 @contextmanager
-def unix_compress_file(f_name: NPath, level: int = 6) -> t.ContextManager[str]:
+def unix_compress_file(f_name: NPath, level: int = 6) -> t.Generator[str, None, None]:
     """(UNIX only) Return path to a compressed version of the input filename"""
     subprocess.run(["gzip", "-kf", f"-{level}", f_name], check=True)
     f_name_gz = f"{f_name}.gz"
@@ -168,7 +170,7 @@ def unix_compress_file(f_name: NPath, level: int = 6) -> t.ContextManager[str]:
 
 
 @contextmanager
-def unix_decompress_file(f_name: NPath) -> t.ContextManager[str]:
+def unix_decompress_file(f_name: NPath) -> t.Generator[str, None, None]:
     """(UNIX only) Return path to a compressed version of the input filename"""
     subprocess.run(["gunzip", "-kf", f_name], check=True)
     f_name_gz = f"{f_name}.gz"
@@ -179,7 +181,7 @@ def unix_decompress_file(f_name: NPath) -> t.ContextManager[str]:
 
 
 @contextmanager
-def compress_file(f_name: NPath, level: int = 6) -> t.ContextManager[str]:
+def compress_file(f_name: NPath, level: int = 6) -> t.Generator[str, None, None]:
     """(X-Plat) Return path to a compressed version of the input filename"""
     f_name_gz = f"{f_name}.gz"
     with open(f_name, "rb") as f_in, gzip.open(f_name_gz, "wb", compresslevel=level) as f_out:
@@ -192,8 +194,18 @@ def compress_file(f_name: NPath, level: int = 6) -> t.ContextManager[str]:
             os.unlink(f_name_gz)
 
 
+def inmemory_compress(content: io.BytesIO) -> io.BytesIO:
+    """(x-plat) Memory-based gzip compression"""
+    content.seek(0)
+    zbuf = io.BytesIO()
+    with gzip.GzipFile(mode="wb", fileobj=zbuf, mtime=0.0) as zfile:
+        zfile.write(content.read())
+    zbuf.seek(0)
+    return zbuf
+
+
 @contextmanager
-def temp_workdir() -> t.ContextManager[None]:
+def temp_workdir() -> t.Generator[str, None, None]:
     """Set working dir to a tempdir for duration of context"""
     with TemporaryDirectory() as tmp_dir:
         curdir = os.getcwd()
@@ -205,7 +217,7 @@ def temp_workdir() -> t.ContextManager[None]:
 
 
 @contextmanager
-def pushd(directory: NPath, pre_create: bool = False, post_remove: bool = False) -> t.ContextManager[None]:
+def pushd(directory: NPath, pre_create: bool = False, post_remove: bool = False) -> t.Generator[None, None, None]:
     """Switch dir and push it onto the (call-)stack"""
     directory = Path(directory)
     cwd = os.getcwd()
@@ -261,49 +273,16 @@ def timestamp(x: t.Optional[datetime.datetime] = None) -> str:
     return f'{x.isoformat(timespec="seconds")}{"" if x.tzinfo else "Z"}'
 
 
-def dict_drop_empty(xs: t.Dict, none_only: bool = False) -> t.Dict:
+def dict_drop_empty(xs: t.Optional[t.Dict] = None, none_only: bool = False, **kwargs) -> t.Dict:
     """Return a new dict with the empty/falsey values removed"""
+    xs = {**(xs or {}), **kwargs}
+
     if none_only:
         return {k: v for (k, v) in xs.items() if v is not None}
     else:
         return {k: v for (k, v) in xs.items() if v or isinstance(v, bool)}
 
 
-def process_notebook(input_file: Path, output_file: Path):
-    """
-    Strips the output of the jupyter notebook provided as input and also removes cells tagged as "exclude".
-    input_file: file object or path of jupyter notebook that needs to be processed
-    output_file: path of the output file
-    """
-    import nbconvert
-    from packaging.version import parse as parse_version
-
-    # check available nbconvert version and raise error if it is not >=6.0.0
-    if parse_version(nbconvert.__version__) < parse_version("6.0.0"):
-        raise DPError("Source file upload only works with nbconvert >= 6.0.0. Run pip install 'nbconvert>=6.0.0'")
-
-    from nbconvert import NotebookExporter
-    from nbconvert.preprocessors import ClearOutputPreprocessor, TagRemovePreprocessor
-    from nbconvert.preprocessors.sanitize import SanitizeHTML
-    from traitlets.config import Config
-
-    if input_file.suffix != ".ipynb":
-        raise DPError("Source file should be a jupyter notebook.")
-
-    # Setup config
-    c = Config()
-    # Configure tag removal preprocessors
-    c.TagRemovePreprocessor.remove_cell_tags = ("exclude",)
-    exporter = NotebookExporter(config=c)
-    exporter.register_preprocessor(ClearOutputPreprocessor(config=c), True)
-    exporter.register_preprocessor(TagRemovePreprocessor(config=c), True)
-    exporter.register_preprocessor(SanitizeHTML(config=c), True)
-    # Run exporter
-    output, _ = exporter.from_filename(input_file)
-    # write output to file
-    Path(output_file).write_text(output)
-
-
 def utf_read_text(file: Path) -> str:
     """Encoding-aware text reader
     - handles cases like on windows where a file is UTF-8, but default locale is windows-1252
@@ -320,3 +299,10 @@ def utf_read_text(file: Path) -> str:
     else:
         # for linux/macOS assume utf-8
         return file.read_text()
+
+
+def get_app_file_params(params: t.List[SDict]) -> t.List[str]:
+    """
+    Returns the list of App param names that are of type `file`
+    """
+    return [p["name"] for p in params if p["type"] == "file"]
